from setuptools import setup

setup(
    name = 'TCPipelineUtils',
    version = '1.0.4',
    author = 'Matheus Tramontini Lopes',
    author_email = 'matheus.lopes@tc.com.br',
    packages = ['TCPipelineUtils'],
    install_requires = [
        "TCGCSUtils==1.0.*",
        "numpy==1.23.*",
        "pandas==1.4.*"
    ],
    description='A lib to make easy to create a pipeline in TC',
)



import pandas as pd
from TCGCSUtils import GCSReader
import logging
import json
logging.basicConfig(format='%(levelname)s -> %(message)s', level=logging.INFO)


class BaseSource(object):
    def __init__(self, service_account_json: str, project: str) -> None:
        self.service_account = service_account_json
        self.project = project
        self.reader = GCSReader(service_account_info=self.service_account, gcp_project=self.project)

    def read_gcs(self, bucket: str, file_path: str, files_format: str, time_execution_value=None,
                 time_execution_type=None):

        if files_format == 'json':
            if time_execution_type is None:
                logging.info('Reading all json files')
                files_list = self.reader.read_from_json(
                    bucket,
                    file_path
                )
            else:
                logging.info(f'Reading json files from the last {time_execution_value} {time_execution_type}')
                files_list = self.reader.read_from_json(
                    bucket,
                    file_path,
                    delta_time_kwargs={time_execution_type: time_execution_value}
                )
        else:
            if time_execution_type is None:
                logging.info('Reading all parquet files')
                files_list = self.reader.read_from_parquet(
                    bucket,
                    file_path
                )
            else:
                logging.info(f'Reading all parquet files from the last {time_execution_value} {time_execution_type}')
                files_list = self.reader.read_from_parquet(
                    bucket,
                    file_path,
                    delta_time_kwargs={time_execution_type: time_execution_value}
                )

        if files_list is None:
            return None

        return files_list

    @staticmethod
    def get_raw_df(files_list: list, is_mongo: bool) -> pd.DataFrame:
        df_files_list = []
        logging.info('Starting to read files list')
        for msg in files_list:
            if msg['op'] == 'd':
                if is_mongo:
                    data = json.loads(msg['before'])
                else:
                    data = msg['before']
                data['__deleted'] = True
            else:
                if is_mongo:
                    data = json.loads(msg['after'])
                else:
                    data = msg['after']
                data['__deleted'] = False
            df_files_list.append(data)

        logging.info('Creating the dataframe')
        raw_df = pd.DataFrame.from_records(df_files_list)

        return raw_df



import numpy as np
import pandas as pd
import logging

logging.basicConfig(format='%(levelname)s -> %(message)s', level=logging.INFO)


class PipelineTransformations(object):

    @staticmethod
    def clean_df(df):
        df = df.replace({np.nan: None, '': None, 'none': None})

        return df

    @staticmethod
    def transform_data_field(df: pd.DataFrame, cols: list, time_unit='ms') -> pd.DataFrame:
        for col in cols:
            df[col] = pd.to_datetime(df[col], unit=time_unit)

        return df

    @staticmethod
    def remove_mongo_format(df: pd.DataFrame, mongo_subset_dict: dict) -> pd.DataFrame:
        for key, value in mongo_subset_dict.items():
            df[key] = df.get(key).apply(lambda row: row.get(value) if row is not np.nan else None)

        return df

    @staticmethod
    def explode_dict_to_columns(df: pd.DataFrame, columns_to_explode: list):
        for col in columns_to_explode:
            df = pd.concat([df.drop([col], axis=1), df[col].apply(pd.Series)], axis=1)

        return df

    @staticmethod
    def explode_list_to_columns(df: pd.DataFrame, columns_to_explode: list):
        for col in columns_to_explode:
            df = df.explode(col)

        return df

    @staticmethod
    def get_value_from_request(request_json: dict, value: str):
        if request_json and value in request_json:
            return request_json[value]
        else:
            raise Exception(f'No {value} in HTTP call')




import pandas as pd
from TCGCSUtils import GCSWriter
import logging

logging.basicConfig(format='%(levelname)s -> %(message)s', level=logging.INFO)


class BaseSink(object):
    def __init__(self, service_account_json: str, project: str) -> None:
        self.service_account = service_account_json
        self.project = project
        self.writer = GCSWriter(service_account_info=self.service_account, gcp_project=self.project)

    def write_gcs(self, df: pd.DataFrame, bucket: str, file_path: str, file_name: str, files_format: str) -> None:

        if files_format == 'json':
            logging.info(f'Writing json into {bucket} at {file_path}/{file_name}')
            self.writer.write_json(df, bucket, file_path, file_name)
        else:
            logging.info(f'Writing parquet into {bucket} at {file_path}/{file_name}')
            self.writer.write_parquet(df, bucket, file_path, file_name)

        logging.info('Files saved')